@@ -168,6 +168,15 @@ struct pdu_end_of_data_v1 {
     uint32_t expire_interval;
 };
 
+struct recv_loop_cleanup_args {
+    struct pdu_ipv4 *ipv4_pdus;
+    struct pdu_ipv6 *ipv6_pdus;
+    struct pdu_router_key *router_key_pdus;
+};
+
+
+static void recv_loop_cleanup(void *p);
+
 static int rtr_send_error_pdu_from_network(const struct rtr_socket *rtr_socket,
                                            const void *erroneous_pdu,
                                            const uint32_t erroneous_pdu_len,
@@ -486,10 +495,6 @@ static bool rtr_pdu_check_size (const struct pdu_header *pdu) {
       break;
     }
 
-    if ((err_msg_len > 0) && (((uint8_t*)err_pdu)[min_size-1] != 0)) {
-        RTR_DBG1("Error msg is not null terminated!");
-        break;
-    }
     retval = true;
     break;
   case SERIAL_QUERY:
@@ -720,16 +725,13 @@ static int rtr_handle_error_pdu(struct rtr_socket *rtr_socket, const void *buf)
         break;
     }
 
-    const uint32_t len_err_txt = ntohl(*((uint32_t *) (pdu->rest + pdu->len_enc_pdu)));
+    const uint32_t len_err_txt = *((uint32_t *) (pdu->rest + pdu->len_enc_pdu));
     if (len_err_txt > 0) {
         if ((sizeof(pdu->ver) + sizeof(pdu->type) + sizeof(pdu->error_code) + sizeof(pdu->len) + sizeof(pdu->len_enc_pdu) + pdu->len_enc_pdu + 4 + len_err_txt) != pdu->len)
             RTR_DBG1("error: Length of error text contains an incorrect value");
         else {
-            //assure that the error text contains an terminating \0 char
-            char txt[len_err_txt + 1];
-            char *pdu_txt = (char *) pdu->rest + pdu->len_enc_pdu + 4;
-            snprintf(txt, len_err_txt + 1, "%s", pdu_txt);
-            RTR_DBG("Error PDU included the following error msg: \'%s\'", txt);
+            char *pdu_txt = (char *) pdu->rest + pdu->len_enc_pdu + sizeof(len_err_txt);
+            RTR_DBG("Error PDU included the following error msg: \'%.*s\'", len_err_txt, pdu_txt);
         }
     }
 
@@ -991,7 +993,17 @@ static int rtr_update_spki_table(struct rtr_socket* rtr_socket, struct spki_tabl
     return RTR_SUCCESS;
 }
 
-int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
+
+void recv_loop_cleanup(void *p) {
+    struct recv_loop_cleanup_args *args = p;
+    lrtr_free(args->ipv4_pdus);
+    lrtr_free(args->ipv6_pdus);
+    lrtr_free(args->router_key_pdus);
+}
+
+
+/* WARNING: This Function has cancelable sections*/
+static int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
     char pdu[RTR_MAX_PDU_LEN];
     enum pdu_type type;
     int retval = RTR_SUCCESS;
@@ -1008,12 +1020,23 @@ int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
     unsigned int router_key_pdus_size = 0;
     unsigned int router_key_pdus_nindex = 0;
 
-    struct pfx_table pfx_shadow_table;
-    struct spki_table spki_shadow_table;
+    struct pfx_table* pfx_shadow_table = NULL;
+    struct spki_table* spki_shadow_table = NULL;
+
+    int oldcancelstate;
+    struct recv_loop_cleanup_args cleanup_args = {
+      .ipv4_pdus = ipv4_pdus,
+      .ipv6_pdus = ipv6_pdus,
+      .router_key_pdus = router_key_pdus};
 
     //receive LRTR_IPV4/IPV6 PDUs till EOD
     do {
+        pthread_cleanup_push(recv_loop_cleanup, &cleanup_args);
+        pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &oldcancelstate);
         retval = rtr_receive_pdu(rtr_socket, pdu, RTR_MAX_PDU_LEN, RTR_RECV_TIMEOUT);
+        pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, &oldcancelstate);
+        pthread_cleanup_pop(0);
+
         if (retval == TR_WOULDBLOCK) {
             rtr_change_socket_state(rtr_socket, RTR_ERROR_TRANSPORT);
             retval = RTR_ERROR;
@@ -1092,8 +1115,15 @@ int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
 
             if (rtr_socket->is_resetting) {
                 RTR_DBG1("Reset in progress creating shadow table for atomic reset");
-                pfx_table_init(&pfx_shadow_table, NULL);
-                pfx_update_table = &pfx_shadow_table;
+                pfx_shadow_table = lrtr_malloc(sizeof(struct pfx_table));
+                if (pfx_shadow_table == NULL) {
+                    RTR_DBG1("Memory allocation for pfx shadow table failed");
+                    retval = RTR_ERROR;
+                    goto cleanup;
+                }
+
+                pfx_table_init(pfx_shadow_table, NULL);
+                pfx_update_table = pfx_shadow_table;
                 if (pfx_table_copy_except_socket(rtr_socket->pfx_table, pfx_update_table, rtr_socket)) {
                     RTR_DBG1("Creation of pfx shadow table failed");
                     rtr_change_socket_state(rtr_socket, RTR_ERROR_FATAL);
@@ -1101,8 +1131,14 @@ int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
                     goto cleanup;
                 }
 
-                spki_table_init(&spki_shadow_table, NULL);
-                spki_update_table = &spki_shadow_table;
+                spki_shadow_table = lrtr_malloc(sizeof(struct spki_table));
+                if (spki_shadow_table == NULL) {
+                    RTR_DBG1("Memory allocation for spki shadow table failed");
+                    retval = RTR_ERROR;
+                    goto cleanup;
+                }
+                spki_table_init(spki_shadow_table, NULL);
+                spki_update_table = spki_shadow_table;
                 if (spki_table_copy_except_socket(rtr_socket->spki_table, spki_update_table, rtr_socket) != SPKI_SUCCESS) {
                     RTR_DBG1("Creation of spki shadow table failed");
                     rtr_change_socket_state(rtr_socket, RTR_ERROR_FATAL);
@@ -1116,7 +1152,7 @@ int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
                 spki_update_table = rtr_socket->spki_table;
             }
 
-            int retval = PFX_SUCCESS;
+            retval = PFX_SUCCESS;
             //add all IPv4 prefix pdu to the pfx_table
             for (unsigned int i = 0; i < ipv4_pdus_nindex; i++) {
                 if (rtr_update_pfx_table(rtr_socket, pfx_update_table, &(ipv4_pdus[i])) == PFX_ERROR) {
@@ -1181,19 +1217,19 @@ int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
             RTR_DBG1("spki data added");
             if (rtr_socket->is_resetting) {
                 RTR_DBG1("Reset finished. Swapping new table in.");
-                pfx_table_swap(rtr_socket->pfx_table, &pfx_shadow_table);
-                spki_table_swap(rtr_socket->spki_table, &spki_shadow_table);
+                pfx_table_swap(rtr_socket->pfx_table, pfx_shadow_table);
+                spki_table_swap(rtr_socket->spki_table, spki_shadow_table);
 
                 if (rtr_socket->pfx_table->update_fp) {
                     RTR_DBG1("Calculating and notifying pfx diff");
-                    pfx_table_notify_diff(rtr_socket->pfx_table, &pfx_shadow_table, rtr_socket);
+                    pfx_table_notify_diff(rtr_socket->pfx_table, pfx_shadow_table, rtr_socket);
                 } else {
                     RTR_DBG1("No pfx update callback. Skipping diff");
                 }
 
                 if (rtr_socket->spki_table->update_fp) {
                     RTR_DBG1("Calculating and notifying spki diff");
-                    spki_table_notify_diff(rtr_socket->spki_table, &spki_shadow_table, rtr_socket);
+                    spki_table_notify_diff(rtr_socket->spki_table, spki_shadow_table, rtr_socket);
                 } else {
                     RTR_DBG1("No spki update callback. Skipping diff");
                 }
@@ -1222,8 +1258,15 @@ int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
 
     if (rtr_socket->is_resetting) {
         RTR_DBG1("Freeing shadow tables.");
-        pfx_table_free_without_notify(&pfx_shadow_table);
-        spki_table_free_without_notify(&spki_shadow_table);
+        if (pfx_shadow_table != NULL) {
+            pfx_table_free_without_notify(pfx_shadow_table);
+            lrtr_free(pfx_shadow_table);
+        }
+
+        if (spki_shadow_table != NULL) {
+            spki_table_free_without_notify(spki_shadow_table);
+            lrtr_free(spki_shadow_table);
+        }
         rtr_socket->is_resetting = false;
     }
 
@@ -1233,13 +1276,18 @@ int rtr_sync_receive_and_store_pdus(struct rtr_socket *rtr_socket){
     return retval;
 }
 
+/* WARNING: This Function has cancelable sections */
 int rtr_sync(struct rtr_socket *rtr_socket)
 {
     char pdu[RTR_MAX_PDU_LEN];
     enum pdu_type type;
 
+    int oldcancelstate;
+
     do {
+        pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &oldcancelstate);
         int rtval = rtr_receive_pdu(rtr_socket, pdu, RTR_MAX_PDU_LEN, RTR_RECV_TIMEOUT);
+        pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, &oldcancelstate);
         //If the cache has closed the connection and we don't have a session_id
         //(no packages where exchanged) we should downgrade.
         if (rtval == TR_CLOSED && rtr_socket->request_session_id) {
