@@ -29,12 +29,12 @@ fi
 cd $SCRIPT_DIR/..
 for i in $CHECKSOURCE; do
 	echo "> check coding style of $i ..."
-    IGNORE="PREFER_KERNEL_TYPES,CONST_STRUCT,OPEN_BRACE"
+    IGNORE="PREFER_KERNEL_TYPES,CONST_STRUCT,OPEN_BRACE,SPDX_LICENSE_TAG,OPEN_ENDED_LINE,UNNECESSARY_PARENTHESES,PREFER_PRINTF,GLOBAL_INITIALISERS,PREFER_PACKED"
     if [[ $i == *"unittest"* ]]; then
         IGNORE="${IGNORE},CAMELCASE"
     fi
         $SCRIPT_DIR/checkpatch.pl -f --strict --no-tree --terse --show-types \
-               --ignore ${IGNORE} $i
+               --max-line-length 120 --ignore ${IGNORE} $i
 
 	if [ $? -ne "0" ]; then
 		EXIT_CODE=1
